@@ -6,17 +6,15 @@
 #       it under the terms of the GNU General Public License as published by
 #       the Free Software Foundation; either version 2 of the License, or
 #       (at your option) any later version.
-#       
 #       This program is distributed in the hope that it will be useful,
 #       but WITHOUT ANY WARRANTY; without even the implied warranty of
 #       MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 #       GNU General Public License for more details.
-#       
 #       You should have received a copy of the GNU General Public License
 #       along with this program; if not, write to the Free Software
 #       Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 #       MA 02110-1301, USA.
-#  
+#
 
 from gi.repository import Gtk
 from gi.repository import Pango
@@ -24,6 +22,7 @@ import gettext
 
 _ = gettext.gettext
 
+
 class InfoBox(Gtk.VBox):
     def __init__(self):
         super(InfoBox, self).__init__()
@@ -56,6 +55,7 @@ class InfoBox(Gtk.VBox):
         self.pack_start(self.bar_box, False, False, 0)
         self.bar_box.pack_end(self.bar, False, False, 0)
 
+
 class Infos(Gtk.HBox):
     def __init__(self):
         super(Infos, self).__init__()
@@ -73,6 +73,7 @@ class Infos(Gtk.HBox):
         self.pack_start(self.icon, False, False, 0)
         self.pack_start(self.box3, False, False, 0)
 
+
 class InfoBar(Gtk.HBox):
     def __init__(self):
         super(InfoBar, self).__init__()
@@ -91,7 +92,7 @@ class ScreenDesc(Gtk.VBox):
         self.icon_box.pack_start(self.icon, False, False, 0)
         self.icon_box.pack_start(self.label, False, False, 0)
         return self.icon_box
-    
+
     def __init__(self):
         super(ScreenDesc, self).__init__()
         self.details = Details()
@@ -109,14 +110,16 @@ class ScreenDesc(Gtk.VBox):
         self.screen_frame.add(self.screen_box)
         self.screen_frame_box.pack_start(self.screen_frame, True, False, 0)
         self.screenbutton_box = Gtk.VBox()
-        self.screenbutton_box.pack_start(self.screen_frame_box, False, False, 0)
+        self.screenbutton_box.pack_start(self.screen_frame_box,
+                                         False, False, 0)
         self.screenbutton_box.pack_start(self.details, False, False, 0)
         self.textview = Gtk.TextView()
         self.textview.set_editable(False)
         self.textview.set_left_margin(5)
         self.textview.set_cursor_visible(False)
         self.textview.set_wrap_mode(Gtk.WrapMode.WORD_CHAR)
-        self.desc_title = self.add_icon_label("<b>"+_("Description")+"</b>", "ascii")
+        self.desc_title = self.add_icon_label(
+            "<b>" + _("Description") + "</b>", "ascii")
         self.check_reviews = Gtk.Button(_("Check for reviews"))
         self.second_box = Gtk.HBox()
         self.second_box.set_spacing(5)
@@ -136,6 +139,7 @@ class ScreenDesc(Gtk.VBox):
         self.pack_start(Gtk.HSeparator(), False, False, 0)
         self.pack_end(self.revs_main, True, True, 0)
 
+
 class Details(Gtk.VBox):
     def __init__(self):
         super(Details, self).__init__()
@@ -145,8 +149,15 @@ class Details(Gtk.VBox):
         for items in (self.version, self.to_download, self.installed):
             items.set_ellipsize(Pango.EllipsizeMode.END)
             self.details_box = Gtk.HBox()
-            self.arrow = Gtk.Arrow()
-            self.arrow.set(Gtk.ArrowType.RIGHT, Gtk.ShadowType.NONE)
+            # Keep the 2 methods, until we figure out why 1 method
+            # crashes on a system, and not on another one.
+            # Reproductible on 2 differnet precise installations.
+            try:
+                self.arrow = Gtk.Arrow(Gtk.ArrowType.RIGHT,
+                                       Gtk.ShadowType.NONE)
+            except TypeError:
+                self.arrow = Gtk.Arrow()
+                self.arrow.set(Gtk.ArrowType.RIGHT, Gtk.ShadowType.NONE)
             self.details_box.pack_start(self.arrow, False, False, 0)
             self.details_box.pack_start(items, False, False, 0)
             self.pack_start(self.details_box, False, False, 0)
