@@ -6,21 +6,20 @@
 #       it under the terms of the GNU General Public License as published by
 #       the Free Software Foundation; either version 2 of the License, or
 #       (at your option) any later version.
-#       
 #       This program is distributed in the hope that it will be useful,
 #       but WITHOUT ANY WARRANTY; without even the implied warranty of
 #       MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 #       GNU General Public License for more details.
-#       
 #       You should have received a copy of the GNU General Public License
 #       along with this program; if not, write to the Free Software
 #       Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 #       MA 02110-1301, USA.
-#  
+#
 
 from gi.repository import Gtk
 import searchentry
 
+
 class Toolbar(Gtk.Toolbar):
     def __init__(self):
         super(Toolbar, self).__init__()
@@ -33,7 +32,7 @@ class Toolbar(Gtk.Toolbar):
         self.vbox = Gtk.VBox()
         for items in self.back_forwards():
             self.insert(items, -1)
-    
+
     def back_forwards(self):
         self.back = Gtk.ToolButton()
         self.back.set_stock_id(Gtk.STOCK_GO_BACK)
@@ -41,7 +40,7 @@ class Toolbar(Gtk.Toolbar):
         self.back.set_sensitive(False)
         self.space = Gtk.SeparatorToolItem()
         return (self.back,)
-    
+
     def add_sections(self, seclist=[], important=True, func=None):
         sectionslist = {}
         self.group = Gtk.RadioButton()
@@ -51,7 +50,8 @@ class Toolbar(Gtk.Toolbar):
         self.group_box.set_spacing(2)
         self.group_icon = Gtk.Image()
         self.group.label = Gtk.Label()
-        self.group_icon.set_from_icon_name(seclist[0][0], Gtk.IconSize.SMALL_TOOLBAR)
+        self.group_icon.set_from_icon_name(
+            seclist[0][0], Gtk.IconSize.SMALL_TOOLBAR)
         self.group.label.set_text(seclist[0][1])
         self.group_box.pack_start(self.group_icon, False, False, 0)
         self.group_box.pack_start(self.group.label, False, False, 0)
@@ -68,7 +68,8 @@ class Toolbar(Gtk.Toolbar):
             self.choose_box.set_spacing(2)
             self.choose_icon = Gtk.Image()
             self.choose.label = Gtk.Label()
-            self.choose_icon.set_from_icon_name(icon, Gtk.IconSize.SMALL_TOOLBAR)
+            self.choose_icon.set_from_icon_name(
+                icon, Gtk.IconSize.SMALL_TOOLBAR)
             self.choose.label.set_text(name)
             self.choose_box.pack_start(self.choose_icon, False, False, 0)
             self.choose_box.pack_start(self.choose.label, False, False, 0)
@@ -90,6 +91,6 @@ class Toolbar(Gtk.Toolbar):
         self.insert(self.entry, -1)
         self.insert(self.settings, -1)
         return sectionslist
-    
+
     def refresh_back_forward(self, can_home):
         self.back.set_sensitive(can_home)
